import {ComponentFixture, TestBed} from '@angular/core/testing';

import {ClinicalExamsComponent} from './clinical-exams.component';
import {of} from 'rxjs';
import {ClinicalObservationsService} from './clinical-observations.service';
import {DataCardService} from '../../api/data-card.service';

describe('ClinicalExamsComponent', () => {
  let component: ClinicalExamsComponent;
  let fixture: ComponentFixture<ClinicalExamsComponent>;
  let obsService: ClinicalObservationsService;
  beforeEach(async () => {
    obsService = {
      observationGroups: of({
        fetuses: [
          {id: '1234', name: 'A', rows: [{id: 'abc', weeksIntoPregnancy: 2, fetusWeightEstimate: '142', date: new Date(2022, 5, 12), activityId: '123abc'}]},
          {id: '123', name: 'B', rows: [
              {id: 'sep', weeksIntoPregnancy: 4, fetusWeightEstimate: '231', date: new Date(2022, 6, 20), activityId: 'fasdart'},
              {id: 'sep123', weeksIntoPregnancy: 5, fetusWeightEstimate: '333', date: new Date(2022, 3, 2), activityId: 'fasdart'}
            ]}
        ],
        mother: {
          rows: [
            {id: '666', activityId: '123abc', date: new Date(2022, 5, 12), weeksIntoPregnancy: 2, pubismeasurement: 122},
            {id: '222', activityId: '234bcd', date: new Date(2022, 6, 20), weeksIntoPregnancy: 4, pubismeasurement: 22}
          ]}
      } as any)
    } as ClinicalObservationsService;
    await TestBed.configureTestingModule({
      declarations: [ ClinicalExamsComponent ],
      providers: [
        { provide: ClinicalObservationsService, useValue: obsService},
        { provide: DataCardService, useValue: {isDataCardClosed: of(false)}}
      ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(ClinicalExamsComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should have a method that can open the measurement modal', () => {
    component.measurementsModal = {isOpen: false} as any;
    expect(component.measurementsModal?.isOpen).toBeFalsy();
    component.createMeasurements();
    expect(component.measurementsModal?.isOpen).toBeTrue();
  });

  it('should have a method that can open the measurement modal for the related activity', () => {
    component.showRelatedActivityModal = {isOpen: false} as any;
    expect(component.showRelatedActivityModal?.isOpen).toBeFalsy();
    component.showActivity('1337');
    expect(component.showRelatedActivityModal?.isOpen).toBeTrue();
    expect(component.showRelatedActivityModal?.activityId).toBe('1337');
  });
});
