import {Component, OnDestroy} from '@angular/core';
import {UserAuthorizationType, UserContextService} from '../services/user-context.service';
import {SorItem, SorService} from '../services/sor.service';
import {FormControl, Validators} from '@angular/forms';
import {Observable, of, Subscription} from 'rxjs';
import {debounceTime, distinctUntilChanged, startWith, switchMap} from 'rxjs/operators';
import {DialogService} from '../modals/dialog/dialog.service';

@Component({
  selector: 'app-role-selector',
  templateUrl: './role-selector.component.html',
  styleUrls: ['./role-selector.component.scss']
})
export class RoleSelectorComponent {
  public selectedRole: UserAuthorizationType | undefined;
  public selectedOrganisation: SorItem | undefined;

  constructor(
    public sorService: SorService,
    public userContextService: UserContextService,
    private dialogService: DialogService
  ) {
    this.userContextService.eligibleRoles$.subscribe(roles => {
      if (roles?.length === 1) {
        this.selectedRole = roles[0];
      }
    });
  }

  public continue(): void {
    if (this.selectedRole && this.selectedOrganisation) {
      try {
        this.userContextService.selectOrganizationSor(this.selectedOrganisation);
        this.userContextService.selectRole(this.selectedRole);
        this.dialogService.close(this);
      } catch (e) {
        // Since this component is both used in the login screen and in a dialog we may not always have a dialog to close
        // - we handle that here but ignoring the "you forgot to open the dialog first"-exception
        if (e.message !== 'Could not close dialog - did you try to close it without opening it?') {
          throw e;
        }
      }
    }
  }

  public logout(): void {
    this.userContextService.logout();
  }
}
