import {Injectable} from '@angular/core';
import {Observable, ReplaySubject} from 'rxjs';
import {environment} from '../../environments/environment';
import {HttpClient} from '@angular/common/http';
import {map, tap} from 'rxjs/operators';
import {HealthCareOrganization} from '@nspop/gm-web-facade-api';

export interface SorItem {
  name: string;
  sorId: string;
  institutionOwnerSorId?: string;
}

export interface SoresLookUpResponse {
  entities: SorItem[];
  additionalRecordsExist: boolean;
}

@Injectable({
  providedIn: 'root'
})
export class SorService {
  public sorLookupOrganizations$: ReplaySubject<HealthCareOrganization[]> = new ReplaySubject<HealthCareOrganization[]>();
  private SOR_LOOKUP_PATH = '/sorlookup';
  private SOR_MATERNITY_UNITS_PATH = '/sorlookup/getmaternityunits';

  constructor(private http: HttpClient) {
    this.http.get<SoresLookUpResponse>(environment.base_path + '/api' + this.SOR_MATERNITY_UNITS_PATH).pipe(
      map(response => response.entities.map(item => ({name: item.name, sorId: item.sorId}))),
      tap(response => this.sorLookupOrganizations$.next(response))
    ).subscribe();
  }

  public lookUp(query: string): Observable<SorItem[]> {
    // @ts-ignore
    return this.http.get<SoresLookUpResponse>(environment.base_path + '/api' + this.SOR_LOOKUP_PATH, {params: {name: query}}).pipe(
      map(response => response.entities),
    );
  }
}
