import { Activity, Observation, ObservationType } from '@nspop/gm-web-facade-api';

export default class ActivityUtil {

  static hasMeasurements(activity: Activity | undefined): boolean {
    return this.hasRegularMeasurements(activity) || this.hasUltraSoundMeasurements(activity);
  }

  static hasRegularMeasurements(activity: Activity | undefined): boolean {
    const observations: Observation[] = activity?.observations || [];
    return observations.some(observation => this.isOfTypeObservationRegularType(observation.type));
  }

  static hasUltraSoundMeasurements(activity: Activity | undefined): boolean {
    const observations: Observation[] = activity?.observations || [];
    return observations.some(observation => this.isOfTypeObservationUltraSoundType(observation.type));
  }

  private static isOfTypeObservationRegularType(type: ObservationType | undefined): boolean {
    if (!type) {
      return false;
    }

    return [
      'weight',
      'blood_pressure',
      'urine',
      'edema',
      'pubis_measurements',
      'fetus_activity',
      'fetus_weight_estimate',
      'fetus_presentation'
    ].includes(type);
  }

  private static isOfTypeObservationUltraSoundType(type: ObservationType | undefined): boolean {
    if (!type) {
      return false;
    }

    return [
      'fetus_weight_estimate_ultrasound',
      'fetus_presentation_ultrasound',
      'cervix',
      'dvp',
      'gestation_age_ultrasound',
      'weight_deviation',
      'amniotic_fluid',
      'flow'
    ].includes(type);
  }
}
